@@ -33,7 +33,7 @@ fi;
 
 # Execute DataHub recipe, based on the recipe id. 
 echo "datahub ${debug_option} ingest run -c ${recipe_file} ${report_option}"
-if (datahub ingest run -c "${recipe_file}" ${report_option}); then
+if (datahub ${debug_option} ingest run -c "${recipe_file}" ${report_option}); then
   exit 0
 else
   exit 1
