@@ -37,6 +37,7 @@ class SubProcessIngestionTaskConfig(ConfigModel):
 class SubProcessIngestionTaskArgs(ConfigModel):
     recipe: str
     version: str = "latest"
+    debug_mode: str = "false" # Expected values are "true" or "false". 
 
 class SubProcessIngestionTask(Task):
 
@@ -72,16 +73,16 @@ class SubProcessIngestionTask(Task):
         # 3. Spin off subprocess to run the run_ingest.sh script
         datahub_version = validated_args.version # The version of DataHub CLI to use. 
         plugins = recipe["source"]["type"] # The source type -- ASSUMPTION ALERT: This should always correspond to the plugin name. 
-        command_script: str = "run_ingest.sh" # TODO: Make sure this is EXECUTABLE.  
+        debug_mode = validated_args.debug_mode
+        command_script: str = "run_ingest.sh" # TODO: Make sure this is EXECUTABLE before running
 
         stdout_lines: deque[str] = deque(maxlen=self.config.max_log_lines)
 
-        # TODO: Inject a token into the recipe to run such that it "just works" (currently, a token is required)
         report_out_file = f"{exec_out_dir}/ingestion_report.json"
 
         logger.info(f'Starting ingestion subprocess for exec_id={exec_id} ({plugins})')
         ingest_process = await asyncio.create_subprocess_exec(
-            *[command_script, exec_id, datahub_version, plugins, self.tmp_dir, f"{exec_out_dir}/recipe.yml", report_out_file],
+            *[command_script, exec_id, datahub_version, plugins, self.tmp_dir, f"{exec_out_dir}/recipe.yml", report_out_file, debug_mode],
             stdout=asyncio.subprocess.PIPE,
             stderr=asyncio.subprocess.STDOUT,
         )
